Crate videocall_types

Crate videocall_types 

Re-exports

pub use callback::Callback;
pub use feature_flags::FeatureFlags;
pub use user_id::is_system_user;
pub use user_id::to_user_id_bytes;
pub use user_id::user_id_bytes_to_string;

Modules

callback
Framework-agnostic callback type.
feature_flags
Feature flags for videocall-rs.
protos
user_id
User identity byte conversion utilities.
validation
Pure validation and normalisation helpers for display names and meeting IDs.

Constants

SYSTEM_USER_ID
System user ID used for server-generated messages (meeting info, meeting started/ended). This is not a real user and should be filtered out in UI/peer management.

Functions

truthy

Type Aliases

Binary
A representation of a value which can be stored and restored as a binary.
Text
A representation of a value which can be stored and restored as a text.