Callback

Struct Callback 

pub struct Callback<IN, OUT = ()> { /* private fields */ }
Universal callback wrapper.

An Rc wrapper is used to make it cloneable.

Implementations

Source

impl<IN, OUT> Callback<IN, OUT>

pub fn emit(&self, value: IN) -> OUT

Calls the callback’s function.

Source

impl<IN> Callback<IN>

pub fn noop() -> Self

Creates a “no-op” callback which can be used when it is not suitable to use an Option<Callback>.

Source

impl<IN: 'static, OUT: 'static> Callback<IN, OUT>

pub fn reform<F, T>(&self, func: F) -> Callback<T, OUT>
where F: Fn(T) -> IN + 'static,

Creates a new callback from another callback and a function. When emitted, calls func first, then emits the result to the original callback.

pub fn filter_reform<F, T>(&self, func: F) -> Callback<T, Option<OUT>>
where F: Fn(T) -> Option<IN> + 'static,

Creates a new callback from another callback and a function. When emitted will call the function and, only if it returns Some(value), will emit value to the original callback.