Framework-agnostic callback type.
Originally based on the Callback type from the Yew framework (MIT licensed),
extracted here so that videocall-client and its consumers do not depend on any
specific UI framework.
Structs
- Callback
- Universal callback wrapper.